==> vlc_2.0.1.orig.tar.xz: vlc-2.0.1/modules/gui/skins2/commands/async_queue.hpp <==
/*****************************************************************************
 * async_queue.hpp
 *****************************************************************************
 * Copyright (C) 2003 the VideoLAN team
 * $Id: 2a89f117e03e2d0102449dfb491bfdf64ae153a8 $
 *
 * Authors: Cyril Deguet     <asmax@via.ecp.fr>
 *          Olivier Teulière <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef ASYNC_QUEUE_HPP
#define ASYNC_QUEUE_HPP

#include "cmd_generic.hpp"

#include <list>
#include <string>

class OSTimer;


/// Asynchronous queue for commands
class AsyncQueue: public SkinObject
{
public:
    /// Get the instance of AsyncQueue
    /// Returns NULL if initialization failed.
    static AsyncQueue *instance( intf_thread_t *pIntf );

    /// Destroy the instance of AsyncQueue
    static void destroy( intf_thread_t *pIntf );

    /// Add a command in the queue, after having removed the commands
    /// of the same type already in the queue if needed
    void push( const CmdGenericPtr &rcCommand, bool removePrev = true );

    /// Remove the commands of the given type
    void remove( const string &rType , const CmdGenericPtr &rcCommand );

    /// Flush the queue and execute the commands
    void flush();

private:
    /// Command queue
    typedef std::list<CmdGenericPtr> cmdList_t;
    cmdList_t m_cmdList;
    /// Timer
    OSTimer *m_pTimer;
    /// Mutex
    vlc_mutex_t m_lock;

    // Private because it is a singleton
    AsyncQueue( intf_thread_t *pIntf );
    virtual ~AsyncQueue();

    // Callback to flush the queue
    DEFINE_CALLBACK( AsyncQueue, Flush );
};


#endif

==> vlc_3.0.1.orig.tar.xz: vlc-3.0.1/modules/gui/skins2/commands/async_queue.hpp <==
/*****************************************************************************
 * async_queue.hpp
 *****************************************************************************
 * Copyright (C) 2003 the VideoLAN team
 * $Id: 9288465e485c472e5f6269a655a9e3f1dd03ed83 $
 *
 * Authors: Cyril Deguet     <asmax@via.ecp.fr>
 *          Olivier Teulière <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef ASYNC_QUEUE_HPP
#define ASYNC_QUEUE_HPP

#include "cmd_generic.hpp"

#include <list>
#include <string>

class OSTimer;


/// Asynchronous queue for commands
class AsyncQueue: public SkinObject
{
public:
    /// Get the instance of AsyncQueue
    /// Returns NULL if initialization failed.
    static AsyncQueue *instance( intf_thread_t *pIntf );

    /// Destroy the instance of AsyncQueue
    static void destroy( intf_thread_t *pIntf );

    /// Add a command in the queue, after having removed the commands
    /// of the same type already in the queue if needed
    void push( const CmdGenericPtr &rcCommand, bool removePrev = true );

    /// Remove the commands of the given type
    void remove( const std::string &rType , const CmdGenericPtr &rcCommand );

    /// Flush the queue and execute the commands
    void flush();

private:
    /// Command queue
    typedef std::list<CmdGenericPtr> cmdList_t;
    cmdList_t m_cmdList;
    /// Timer
    OSTimer *m_pTimer;
    /// Mutex
    vlc_mutex_t m_lock;

    // Private because it is a singleton
    AsyncQueue( intf_thread_t *pIntf );
    virtual ~AsyncQueue();

    // Callback to flush the queue
    DEFINE_CALLBACK( AsyncQueue, Flush );
};


#endif
